/*
 *  -*- Mode: ANSI C -*-
 *  $Id: flwtfilt.h,v 1.3 1996/08/16 17:23:24 fernande Exp $
 *  $Source: /sgi.acct/sweldens/cvs/liftpack/include/flwtfilt.h,v $
 *  Author: Fernandez, Gabriel
 *
 *  Declares the functions that find the lifting coefficients used
 *  in the updating of the lambda coefficients.
 */
/* do not edit anything above this line */

#ifndef __FLWTFILT_H__
#define __FLWTFILT_H__

#include "flwtdef.h"

/*
 * Type of filter operator.
 * LINEAR : all wavelet coefficients are multiplied by the same factor
 *          (beta)^j,  where j is the current level.
 * CIRCULAR : beta factors depend on the current position of the coefficient
 *            in a circle. That is, beta is a function of x^2 + y^2 = r^2.
 * RECTANGULAR : beta factors depend on the position of the coefficient
 *               in a rectangle.
 */
typedef enum {
    LINEAR,        /* linear Beta operator */
    CIRCULAR,      /* circular Beta operator */
    RECTANGULAR,   /* rectangular Beta operator */
    FUNCTION       /* custom filter function */
} FilterMode;

typedef struct {
    FilterMode mode;     /* type of filter */
    Flt val1,            /* value 1 of Beta */
        val2;            /* value 2 of Beta */
    char func[256];      /* generic filter function */
} Beta;

/* Inquire the user about the kind of filter that has to be applied */
extern Beta
FilterQuery ( void );

/* Application Program Interface for the filter operator */
extern void
FilterAPI ( Matrix __Data, const int __cols, const int __rows,
                           const int __N, const int __nTilde,
                           const Beta __beta, const int __levels );

/* Apply a Beta factor to the Gamma coefficients */
extern void
FLWTFilter2D ( Matrix __Data, const int __cols, const int __rows,
                              const int __N, const int __nTilde,
                              const Beta __beta, const int __levels );

#endif /* __FLWTFILT_H__ */
